@@ -1,4 +1,4 @@
-use std::arch::x86_64::*;
+use core::arch::x86_64::*;
 
 use super::sse4;
 use crate::pixels::U16x2;
