@@ -1,5 +1,5 @@
-use std::arch::x86_64::*;
-use std::mem::transmute;
+use core::arch::x86_64::*;
+use core::mem::transmute;
 
 use crate::convolution::optimisations::Normalizer16;
 use crate::pixels::U8x4;
